@@ -2,5 +2,5 @@ def UpperName(name):
   newname = ""
   splitName = name.split(" ")
   for name in splitName:
-    newname += name.capatalize() + " 
+    newname += name.capatalize() + " "
   return newname[1:]
\ No newline at end of file
